Author: Jean-Philippe Meuret
Keywords: distance, sampling, mcds, report, pyaudisam, validation, pre-analysis

PyAuDiSam Validation: Pre-analyses
Pre-analysis results report
Easy and parallel run through MCDSPreAnalyser

#### Table of contents

- Results: the essence
- Traceability

## Results: the essence

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Hectare for areas.

Confidence value interval: If not listed in table below, please note that ALL analyses have been run with the same value: 95% .

Adjustment term selection criterion: If not listed in table below, please note that ALL analyses have been run with the same value: AIC .

Note: Most figures have been rounded for readability, but 'CoefVar Density' have been further modified : converted to %

Click on analysis number to get to detailed report

| Sample & Model | Results (1/2) | Results (2/2) | Standard distance histogram | Detection probability density (PDF) | Detection probability
--- | --- | --- | --- | --- | --- | ---
01 |
NumEchant | 0
Espèce | Sylvia atricapilla
Passage | b
Adulte | m
Durée | 5mn
NTot Obs | 137
Min Dist | 13.7214
Max Dist | 488.188
Mod Key Fn | HAZARD
Mod Adj Ser | COSINE
ExCod | 2
NObs | 137
Effort | 94
AIC | 1525.3
Chi2 P | 0.35
KS P | 0.63
CoefVar Density | 15.9
Qual Bal 1 | 0.7
Qual Bal 2 | 0.67
Qual Bal 3 | 0.68
PDetec | 0.071
EDR/ESW | 130.3
Density | 0.27
Min Density | 0.2
Max Density | 0.37
Number | 656
Min Number | 480
Max Number | 896
02 |
NumEchant | 1
Espèce | Sylvia atricapilla
Passage | b
Adulte | m
Durée | 10mn
NTot Obs | 207
Min Dist | 8.37568
Max Dist | 488.188
Mod Key Fn | HAZARD
Mod Adj Ser | COSINE
ExCod | 2
NObs | 207
Effort | 94
AIC | 2338.7
Chi2 P | 0.03
KS P | 0.66
CoefVar Density | 13.6
Qual Bal 1 | 0.47
Qual Bal 2 | 0.47
Qual Bal 3 | 0.48
PDetec | 0.082
EDR/ESW | 140
Density | 0.36
Min Density | 0.27
Max Density | 0.47
Number | 858
Min Number | 658
Max Number | 1119
03 |
NumEchant | 2
Espèce | Sylvia atricapilla
Passage | a+b
Adulte | m
Durée | 5mn
NTot Obs | 261
Min Dist | 10.8433
Max Dist | 488.188
Mod Key Fn | HAZARD
Mod Adj Ser | COSINE
ExCod | 2
NObs | 261
Effort | 190
AIC | 2870.1
Chi2 P | 0
KS P | 0.6
CoefVar Density | 12.1
Qual Bal 1 | 0.18
Qual Bal 2 | 0.21
Qual Bal 3 | 0.21
PDetec | 0.063
EDR/ESW | 122.4
Density | 0.29
Min Density | 0.23
Max Density | 0.37
Number | 700
Min Number | 552
Max Number | 888
04 |
NumEchant | 3
Espèce | Sylvia atricapilla
Passage | a+b
Adulte | m
Durée | 10mn
NTot Obs | 388
Min Dist | 1.21209
Max Dist | 511.41
Mod Key Fn | HAZARD
Mod Adj Ser | COSINE
ExCod | 2
NObs | 388
Effort | 190
AIC | 4348.9
Chi2 P | 0
KS P | 0.63
CoefVar Density | 10.1
Qual Bal 1 | 0.37
Qual Bal 2 | 0.39
Qual Bal 3 | 0.39
PDetec | 0.068
EDR/ESW | 133.4
Density | 0.37
Min Density | 0.3
Max Density | 0.45
Number | 876
Min Number | 718
Max Number | 1068
05 |
NumEchant | 4
Espèce | Turdus merula
Passage | b
Adulte | m
Durée | 5mn
NTot Obs | 131
Min Dist | 2.92858
Max Dist | 714.126
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 131
Effort | 94
AIC | 1579.5
Chi2 P | 0.29
KS P | 0.38
CoefVar Density | 16
Qual Bal 1 | 0.62
Qual Bal 2 | 0.48
Qual Bal 3 | 0.49
PDetec | 0.03
EDR/ESW | 123.2
Density | 0.29
Min Density | 0.21
Max Density | 0.4
Number | 702
Min Number | 513
Max Number | 959
06 |
NumEchant | 5
Espèce | Turdus merula
Passage | b
Adulte | m
Durée | 10mn
NTot Obs | 220
Min Dist | 2.92858
Max Dist | 785.995
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 220
Effort | 94
AIC | 2682
Chi2 P | 0.68
KS P | 0.71
CoefVar Density | 10.9
Qual Bal 1 | 0.83
Qual Bal 2 | 0.63
Qual Bal 3 | 0.64
PDetec | 0.026
EDR/ESW | 127.4
Density | 0.46
Min Density | 0.37
Max Density | 0.57
Number | 1101
Min Number | 890
Max Number | 1363
07 |
NumEchant | 6
Espèce | Turdus merula
Passage | a+b
Adulte | m
Durée | 5mn
NTot Obs | 231
Min Dist | 2.92858
Max Dist | 714.126
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 231
Effort | 190
AIC | 2743.4
Chi2 P | 0.8
KS P | 0.9
CoefVar Density | 12
Qual Bal 1 | 0.92
Qual Bal 2 | 0.69
Qual Bal 3 | 0.7
PDetec | 0.024
EDR/ESW | 109.8
Density | 0.32
Min Density | 0.25
Max Density | 0.41
Number | 770
Min Number | 608
Max Number | 974
08 |
NumEchant | 7
Espèce | Turdus merula
Passage | a+b
Adulte | m
Durée | 10mn
NTot Obs | 400
Min Dist | 2.92858
Max Dist | 785.995
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 400
Effort | 190
AIC | 4795.9
Chi2 P | 0.33
KS P | 0.83
CoefVar Density | 8.7
Qual Bal 1 | 0.8
Qual Bal 2 | 0.61
Qual Bal 3 | 0.62
PDetec | 0.022
EDR/ESW | 116.3
Density | 0.5
Min Density | 0.42
Max Density | 0.59
Number | 1189
Min Number | 1002
Max Number | 1409
09 |
NumEchant | 8
Espèce | Luscinia megarhynchos
Passage | b
Adulte | m
Durée | 5mn
NTot Obs | 57
Min Dist | 32.7403
Max Dist | 1005.39
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 57
Effort | 94
AIC | 715.3
Chi2 P | 0.27
KS P | 0.84
CoefVar Density | 21.7
Qual Bal 1 | 0.71
Qual Bal 2 | 0.53
Qual Bal 3 | 0.54
PDetec | 0.023
EDR/ESW | 153.7
Density | 0.08
Min Density | 0.05
Max Density | 0.12
Number | 196
Min Number | 128
Max Number | 300
10 |
NumEchant | 9
Espèce | Luscinia megarhynchos
Passage | b
Adulte | m
Durée | 10mn
NTot Obs | 84
Min Dist | 32.7403
Max Dist | 1005.39
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 84
Effort | 94
AIC | 1052.4
Chi2 P | 0.99
KS P | 0.99
CoefVar Density | 18.6
Qual Bal 1 | 0.94
Qual Bal 2 | 0.69
Qual Bal 3 | 0.7
PDetec | 0.025
EDR/ESW | 158.4
Density | 0.11
Min Density | 0.08
Max Density | 0.16
Number | 272
Min Number | 189
Max Number | 392
11 |
NumEchant | 10
Espèce | Luscinia megarhynchos
Passage | a+b
Adulte | m
Durée | 5mn
NTot Obs | 107
Min Dist | 14.4337
Max Dist | 1005.39
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 107
Effort | 190
AIC | 1331.4
Chi2 P | 0.75
KS P | 0.97
CoefVar Density | 18.1
Qual Bal 1 | 0.88
Qual Bal 2 | 0.65
Qual Bal 3 | 0.66
PDetec | 0.022
EDR/ESW | 148.9
Density | 0.08
Min Density | 0.06
Max Density | 0.12
Number | 194
Min Number | 136
Max Number | 276
12 |
NumEchant | 11
Espèce | Luscinia megarhynchos
Passage | a+b
Adulte | m
Durée | 10mn
NTot Obs | 156
Min Dist | 14.4337
Max Dist | 1005.39
Mod Key Fn | NEXPON
Mod Adj Ser | COSINE
ExCod | 1
NObs | 156
Effort | 190
AIC | 1942.1
Chi2 P | 0.82
KS P | 0.96
CoefVar Density | 15.7
Qual Bal 1 | 0.93
Qual Bal 2 | 0.68
Qual Bal 3 | 0.7
PDetec | 0.023
EDR/ESW | 153.5
Density | 0.11
Min Density | 0.08
Max Density | 0.15
Number | 266
Min Number | 196
Max Number | 362

## Traceability

### Samples

| Espèce | Passage | Adulte | Durée | AbrevEchant | NumEchant
--- | --- | --- | --- | --- | --- | ---
0 | Sylvia atricapilla | b | m | 5mn | SylvAtri-b-m-5mn | 0
1 | Sylvia atricapilla | b | m | 10mn | SylvAtri-b-m-10mn | 1
2 | Sylvia atricapilla | a+b | m | 5mn | SylvAtri-ab-m-5mn | 2
3 | Sylvia atricapilla | a+b | m | 10mn | SylvAtri-ab-m-10mn | 3
4 | Turdus merula | b | m | 5mn | TurdMeru-b-m-5mn | 4
5 | Turdus merula | b | m | 10mn | TurdMeru-b-m-10mn | 5
6 | Turdus merula | a+b | m | 5mn | TurdMeru-ab-m-5mn | 6
7 | Turdus merula | a+b | m | 10mn | TurdMeru-ab-m-10mn | 7
8 | Luscinia megarhynchos | b | m | 5mn | LuscMega-b-m-5mn | 8
9 | Luscinia megarhynchos | b | m | 10mn | LuscMega-b-m-10mn | 9
10 | Luscinia megarhynchos | a+b | m | 5mn | LuscMega-ab-m-5mn | 10
11 | Luscinia megarhynchos | a+b | m | 10mn | LuscMega-ab-m-10mn | 11

### Models

| keyFn | adjSr | estCrit | cvInt
--- | --- | --- | --- | ---
0 | HNORMAL | COSINE | AIC | 95
1 | HAZARD | COSINE | AIC | 95
2 | UNIFORM | COSINE | AIC | 95
3 | NEXPON | COSINE | AIC | 95
4 | HNORMAL | POLY | AIC | 95
5 | HAZARD | POLY | AIC | 95
6 | UNIFORM | POLY | AIC | 95
7 | NEXPON | POLY | AIC | 95
8 | HNORMAL | HERMITE | AIC | 95
9 | HAZARD | HERMITE | AIC | 95
10 | UNIFORM | HERMITE | AIC | 95
11 | NEXPON | HERMITE | AIC | 95

### Analyser

| Value
--- | ---
Zone | ACDC
Surface | 2400
distanceUnit | Meter
areaUnit | Hectare
runMethod | subprocess.run
runTimeOut | 300
surveyType | Point
distanceType | Radial
clustering | False
defEstimKeyFn | UNIFORM
defEstimAdjustFn | POLY
defEstimCriterion | AIC
defCVInterval | 95
defMinDist |
defMaxDist |
defFitDistCuts |
defDiscrDistCuts |

### Computing platform

| Version
--- | ---
os | Windows Enterprise 10.0.22621 (64bit)
processor | Intel64 Family 6 Model 165 Stepping 2, GenuineIntel, 12 CPUs
python | cpython (win32) R3.8.17 | packaged by conda-forge | (default, Jun 16 2023, 07:01:59) [MSC v.1929 64 bit (AMD64)]
numpy | 1.24.4
pandas | 1.2.5
zoopt | 0.4.0
matplotlib | 3.7.2
jinja2 | 3.1.3
pyaudisam | 1.0.3-b1
DS engine | C:/PortableApps/Distance 752/MCDS.exe

###### Generated on 07/04/2024 21:24:40 with Python 3.8.17, NumPy 1.24.4, Pandas 1.2.5, ZOOpt 0.4.0, Matplotlib 3.7.2, Jinja 3.1.3 ... and PyAuDiSam 1.0.3-b1, with icons from Font Awesome (sources : valtests-ds-params.py, ) .